@@ -51,52 +51,59 @@ class xtp(PatternExtractor):
 
     _ALPHABETIC = ascii_letters.encode('ASCII')
     _LEGITIMATE_HOSTS = {
-        'acm.org'             : 1,
-        'adobe.com'           : 1,
-        'aka.ms'              : 1,
-        'apache.org'          : 1,
-        'apple.com'           : 1,
-        'archive.org'         : 2,
-        'azure.com'           : 1,
-        'baidu.com'           : 2,
-        'comodo.net'          : 1,
-        'comodoca.com'        : 1,
-        'curl.haxx.se'        : 1,
-        'digicert.com'        : 1,
-        'dublincore.org'      : 1,
-        'github.com'          : 3,
-        'globalsign.com'      : 1,
-        'globalsign.net'      : 1,
-        'godaddy.com'         : 1,
-        'google.com'          : 4,
-        'gov'                 : 2,
-        'iana.org'            : 1,
-        'intel.com'           : 1,
-        'live.com'            : 1,
-        'microsoft.com'       : 1,
-        'msdn.com'            : 1,
-        'msn.com'             : 1,
-        'office.com'          : 1,
-        'openssl.org'         : 1,
-        'openxmlformats.org'  : 1,
-        'purl.org'            : 1,
-        'python.org'          : 1,
-        'skype.com'           : 1,
-        'sourceforge.net'     : 4,
-        'sway-cdn.com'        : 1,
-        'sway-extensions.com' : 1,
-        'symantec.com'        : 1,
-        'symauth.com'         : 1,
-        'symcb.com'           : 1,
-        'symcd.com'           : 1,
-        'thawte.com'          : 1,
-        'verisign.com'        : 1,
-        'w3.org'              : 1,
-        'wikipedia.org'       : 1,
-        'wolfram.com'         : 1,
-        'xml.org'             : 1,
-        'xmlsoap.org'         : 1,
-        'yahoo.com'           : 1,
+        'acm.org'                 : 1,
+        'adobe.com'               : 1,
+        'aka.ms'                  : 1,
+        'apache.org'              : 1,
+        'apple.com'               : 1,
+        'archive.org'             : 2,
+        'azure.com'               : 1,
+        'baidu.com'               : 2,
+        'comodo.net'              : 1,
+        'comodoca.com'            : 1,
+        'curl.haxx.se'            : 1,
+        'digicert.com'            : 1,
+        'dublincore.org'          : 1,
+        'github.com'              : 3,
+        'globalsign.com'          : 1,
+        'globalsign.net'          : 1,
+        'godaddy.com'             : 1,
+        'google.com'              : 4,
+        'gov'                     : 2,
+        'iana.org'                : 1,
+        'intel.com'               : 1,
+        'live.com'                : 1,
+        'microsoft.com'           : 1,
+        'msdn.com'                : 1,
+        'msn.com'                 : 1,
+        'office.com'              : 1,
+        'openssl.org'             : 1,
+        'openxmlformats.org'      : 1,
+        'purl.org'                : 1,
+        'python.org'              : 1,
+        'skype.com'               : 1,
+        'sourceforge.net'         : 4,
+        'sway-cdn.com'            : 1,
+        'sway-extensions.com'     : 1,
+        'symantec.com'            : 1,
+        'symauth.com'             : 1,
+        'symcb.com'               : 1,
+        'symcd.com'               : 1,
+        'thawte.com'              : 1,
+        'verisign.com'            : 1,
+        'w3.org'                  : 1,
+        'wikipedia.org'           : 1,
+        'wolfram.com'             : 1,
+        'xml.org'                 : 1,
+        'xmlsoap.org'             : 1,
+        'yahoo.com'               : 1,
+        'googleapis.com'          : 1,
+        'fontawesome.com'         : 1,
+        'jquery.com'              : 1,
+        'cdnjs.cloudflare.com'    : 4,
+        'bootstrapcdn.com'        : 2,
+        'jsdelivr.net'            : 2,
+        'office365.com'           : 2,
     }
 
     _DOMAIN_WHITELIST = [
